pub struct HotswapAssets<R: Runtime> { /* private fields */ }Expand description
Custom Assets implementation that checks the filesystem first, then falls back to the embedded assets from the binary.
Implementations